@@ -42,7 +42,7 @@ class TestDeserializeXml(TestCase, SnapshotMixin, DeepCompareMixin):
         # only latest schema will have all data populated in serialized form
         snapshot_name = mksname(get_bom, SchemaVersion.V1_6, OutputFormat.XML)
         expected = get_bom()
-        with open(self.getSnapshotFile(snapshot_name), 'r') as s:
+        with open(self.getSnapshotFile(snapshot_name)) as s:
             bom = Bom.from_xml(s)
         self.assertBomDeepEqual(expected, bom,
                                 fuzzy_deps=get_bom in all_get_bom_funct_with_incomplete_deps)
