@@ -16,10 +16,8 @@
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
 import datetime
-from typing import List
 from unittest import TestCase
 
-from cyclonedx.exception.model import NoPropertiesProvidedException
 from cyclonedx.model import (
     AttachedText,
     Copyright,
@@ -57,8 +55,7 @@ from tests._data.models import (
 class TestModelCommit(TestCase):
 
     def test_no_parameters(self) -> None:
-        with self.assertRaises(NoPropertiesProvidedException):
-            Commit()
+        Commit()  # Does not raise `NoPropertiesProvidedException`
 
     def test_same(self) -> None:
         ia_comitter = IdentifiableAction(timestamp=datetime.datetime.utcnow(), name='The Committer')
@@ -144,17 +141,17 @@ class TestModelComponent(TestCase):
         self.assertNotEqual(c1, c2)
 
     def test_external_references(self) -> None:
-        c = Component(name='test-component')
-        c.external_references.add(ExternalReference(
+        c1 = Component(name='test-component')
+        c1.external_references.add(ExternalReference(
             type=ExternalReferenceType.OTHER,
             url=XsUri('https://cyclonedx.org'),
             comment='No comment'
         ))
-        self.assertEqual(c.name, 'test-component')
-        self.assertIsNone(c.version)
-        self.assertEqual(c.type, ComponentType.LIBRARY)
-        self.assertEqual(len(c.external_references), 1)
-        self.assertEqual(len(c.hashes), 0)
+        self.assertEqual(c1.name, 'test-component')
+        self.assertIsNone(c1.version)
+        self.assertEqual(c1.type, ComponentType.LIBRARY)
+        self.assertEqual(len(c1.external_references), 1)
+        self.assertEqual(len(c1.hashes), 0)
 
         c2 = Component(name='test2-component')
         self.assertEqual(c2.name, 'test2-component')
@@ -172,39 +169,35 @@ class TestModelComponent(TestCase):
         self.assertEqual(len(c.hashes), 0)
 
     def test_component_equal_1(self) -> None:
-        c = Component(name='test-component')
-        c.external_references.add(ExternalReference(
+        c1 = Component(name='test-component')
+        c1.external_references.add(ExternalReference(
             type=ExternalReferenceType.OTHER,
             url=XsUri('https://cyclonedx.org'),
             comment='No comment'
         ))
-
         c2 = Component(name='test-component')
         c2.external_references.add(ExternalReference(
             type=ExternalReferenceType.OTHER,
             url=XsUri('https://cyclonedx.org'),
             comment='No comment'
         ))
-
-        self.assertEqual(c, c2)
+        self.assertEqual(c1, c2)
 
     def test_component_equal_2(self) -> None:
-        props: List[Property] = [
+        props: list[Property] = (
             Property(name='prop1', value='val1'),
-            Property(name='prop2', value='val2')
-        ]
-
-        c = Component(
+            Property(name='prop2', value='val2'),
+        )
+        c1 = Component(
             name='test-component', version='1.2.3', properties=props
         )
         c2 = Component(
             name='test-component', version='1.2.3', properties=props
         )
-
-        self.assertEqual(c, c2)
+        self.assertEqual(c1, c2)
 
     def test_component_equal_3(self) -> None:
-        c = Component(
+        c1 = Component(
             name='test-component', version='1.2.3', properties=[
                 Property(name='prop1', value='val1'),
                 Property(name='prop2', value='val2')
@@ -216,8 +209,16 @@ class TestModelComponent(TestCase):
                 Property(name='prop4', value='val4')
             ]
         )
+        self.assertNotEqual(c1, c2)
 
-        self.assertNotEqual(c, c2)
+    def test_component_equal_4(self) -> None:
+        c1 = Component(
+            name='test-component', version='1.2.3', bom_ref='ref1'
+        )
+        c2 = Component(
+            name='test-component', version='1.2.3', bom_ref='ref2'
+        )
+        self.assertNotEqual(c1, c2)
 
     def test_same_1(self) -> None:
         c1 = get_component_setuptools_simple()
@@ -287,8 +288,7 @@ class TestModelComponent(TestCase):
 class TestModelComponentEvidence(TestCase):
 
     def test_no_params(self) -> None:
-        with self.assertRaises(NoPropertiesProvidedException):
-            ComponentEvidence()
+        ComponentEvidence()  # Does not raise `NoPropertiesProvidedException`
 
     def test_same_1(self) -> None:
         ce_1 = ComponentEvidence(copyright=[Copyright(text='Commercial')])
@@ -312,8 +312,7 @@ class TestModelComponentEvidence(TestCase):
 class TestModelDiff(TestCase):
 
     def test_no_params(self) -> None:
-        with self.assertRaises(NoPropertiesProvidedException):
-            Diff()
+        Diff()  # Does not raise `NoPropertiesProvidedException`
 
     def test_same(self) -> None:
         at = AttachedText(content='A very long diff')
@@ -351,8 +350,8 @@ class TestModelDiff(TestCase):
 class TestModelAttachedText(TestCase):
 
     def test_sort(self) -> None:
-        # expected sort order: (content_type, content, encoding)
-        expected_order = [0, 4, 2, 1, 3]
+        # expected sort order: (content_type, encoding, content)
+        expected_order = [0, 2, 4, 1, 3]
         text = [
             AttachedText(content='a', content_type='a', encoding=Encoding.BASE_64),
             AttachedText(content='a', content_type='b', encoding=Encoding.BASE_64),
@@ -437,23 +436,22 @@ class TestModelPatch(TestCase):
 class TestModelPedigree(TestCase):
 
     def test_no_params(self) -> None:
-        with self.assertRaises(NoPropertiesProvidedException):
-            Pedigree()
+        Pedigree()  # does not raise `NoPropertiesProvidedException`
 
     def test_same_1(self) -> None:
         p1 = get_pedigree_1()
         p2 = get_pedigree_1()
-        self.assertNotEqual(id(p1), id(p2))
-        self.assertEqual(hash(p1), hash(p2))
-        self.assertTrue(p1 == p2)
+        self.assertNotEqual(id(p1), id(p2), 'id')
+        self.assertEqual(hash(p1), hash(p2), 'hash')
+        self.assertTrue(p1 == p2, 'equal')
 
     def test_not_same_1(self) -> None:
         p1 = get_pedigree_1()
         p2 = get_pedigree_1()
         p2.notes = 'Some other notes here'
-        self.assertNotEqual(id(p1), id(p2))
-        self.assertNotEqual(hash(p1), hash(p2))
-        self.assertFalse(p1 == p2)
+        self.assertNotEqual(id(p1), id(p2), 'id')
+        self.assertNotEqual(hash(p1), hash(p2), 'hash')
+        self.assertFalse(p1 == p2, 'equal')
 
 
 class TestModelSwid(TestCase):
@@ -461,20 +459,20 @@ class TestModelSwid(TestCase):
     def test_same_1(self) -> None:
         sw_1 = get_swid_1()
         sw_2 = get_swid_1()
-        self.assertNotEqual(id(sw_1), id(sw_2))
-        self.assertEqual(hash(sw_1), hash(sw_2))
-        self.assertTrue(sw_1 == sw_2)
+        self.assertNotEqual(id(sw_1), id(sw_2), 'id')
+        self.assertEqual(hash(sw_1), hash(sw_2), 'hash')
+        self.assertTrue(sw_1 == sw_2, 'equal')
 
     def test_same_2(self) -> None:
         sw_1 = get_swid_2()
         sw_2 = get_swid_2()
-        self.assertNotEqual(id(sw_1), id(sw_2))
-        self.assertEqual(hash(sw_1), hash(sw_2))
-        self.assertTrue(sw_1 == sw_2)
+        self.assertNotEqual(id(sw_1), id(sw_2), 'id')
+        self.assertEqual(hash(sw_1), hash(sw_2), 'hash')
+        self.assertTrue(sw_1 == sw_2, 'equal')
 
     def test_not_same(self) -> None:
         sw_1 = get_swid_1()
         sw_2 = get_swid_2()
-        self.assertNotEqual(id(sw_1), id(sw_2))
-        self.assertNotEqual(hash(sw_1), hash(sw_2))
-        self.assertFalse(sw_1 == sw_2)
+        self.assertNotEqual(id(sw_1), id(sw_2), 'id')
+        self.assertNotEqual(hash(sw_1), hash(sw_2), 'hash')
+        self.assertFalse(sw_1 == sw_2, 'equal')
