@@ -20,12 +20,18 @@ from decimal import Decimal
 from unittest import TestCase
 
 from cyclonedx.model import XsUri
-from cyclonedx.model.impact_analysis import ImpactAnalysisAffectedStatus
+from cyclonedx.model.impact_analysis import (
+    ImpactAnalysisAffectedStatus,
+    ImpactAnalysisJustification,
+    ImpactAnalysisResponse,
+    ImpactAnalysisState,
+)
 from cyclonedx.model.vulnerability import (
     BomTarget,
     BomTargetVersionRange,
     Vulnerability,
     VulnerabilityAdvisory,
+    VulnerabilityAnalysis,
     VulnerabilityRating,
     VulnerabilityReference,
     VulnerabilityScoreSource,
@@ -188,7 +194,7 @@ class TestModelVulnerability(TestCase):
         datetime2 = datetime1 + timedelta(seconds=5)
 
         # expected sort order: (id, description, detail, source, created, published)
-        expected_order = [0, 6, 1, 7, 2, 8, 3, 9, 4, 10, 5, 11]
+        expected_order = [0, 1, 10, 2, 3, 4, 5, 6, 7, 8, 9, 11]
         vulnerabilities = [
             Vulnerability(bom_ref='0', id='a', description='a', detail='a',
                           source=source1, created=datetime1, published=datetime1),
@@ -258,16 +264,12 @@ class TestModelVulnerabilityReference(TestCase):
         source_b = VulnerabilitySource(name='b')
 
         # expected sort order: ([id], [source])
-        expected_order = [0, 1, 4, 2, 3, 5, 6, 7]
+        expected_order = [2, 3, 1, 0]
         refs = [
+            VulnerabilityReference(id='b', source=source_b),
+            VulnerabilityReference(id='b', source=source_a),
             VulnerabilityReference(id='a', source=source_a),
             VulnerabilityReference(id='a', source=source_b),
-            VulnerabilityReference(id='b', source=source_a),
-            VulnerabilityReference(id='b', source=source_b),
-            VulnerabilityReference(id='a'),
-            VulnerabilityReference(id='b'),
-            VulnerabilityReference(source=source_a),
-            VulnerabilityReference(source=source_b),
         ]
         sorted_refs = sorted(refs)
         expected_refs = reorder(refs, expected_order)
@@ -281,7 +283,7 @@ class TestModelVulnerabilityRating(TestCase):
         method_a = VulnerabilityScoreSource.CVSS_V3_1
 
         # expected sort order: ([severity], [score], [source], [method], [vector], [justification])
-        expected_order = [0, 1, 2, 3, 4, 5, 6, 7]
+        expected_order = [5, 0, 1, 2, 3, 4, 6, 7]
         refs = [
             VulnerabilityRating(severity=VulnerabilitySeverity.HIGH, score=Decimal(10),
                                 source=source_a, method=method_a, vector='a', justification='a'),
@@ -298,6 +300,7 @@ class TestModelVulnerabilityRating(TestCase):
         ]
         sorted_refs = sorted(refs)
         expected_refs = reorder(refs, expected_order)
+        self.maxDiff = None  # gimme all diff on error
         self.assertListEqual(sorted_refs, expected_refs)
 
 
@@ -337,3 +340,24 @@ class TestModelBomTarget(TestCase):
         sorted_targets = sorted(targets)
         expected_targets = reorder(targets, expected_order)
         self.assertListEqual(sorted_targets, expected_targets)
+
+
+class TestModelVulnerabilityAnalysis(TestCase):
+
+    def test_sort(self) -> None:
+        # expected sort order: ([state], [justification], [responses], [detail], [first_issued], [last_updated])
+        expected_order = [3, 1, 0, 2, 5, 4]
+        analyses = [
+            VulnerabilityAnalysis(state=ImpactAnalysisState.EXPLOITABLE),
+            VulnerabilityAnalysis(state=ImpactAnalysisState.EXPLOITABLE,
+                                  responses=[ImpactAnalysisResponse.CAN_NOT_FIX]),
+            VulnerabilityAnalysis(state=ImpactAnalysisState.NOT_AFFECTED,
+                                  justification=ImpactAnalysisJustification.CODE_NOT_PRESENT),
+            VulnerabilityAnalysis(state=ImpactAnalysisState.EXPLOITABLE,
+                                  justification=ImpactAnalysisJustification.REQUIRES_ENVIRONMENT),
+            VulnerabilityAnalysis(first_issued=datetime(2024, 4, 4), last_updated=datetime(2025, 5, 5)),
+            VulnerabilityAnalysis(first_issued=datetime(2023, 3, 3), last_updated=datetime(2023, 3, 3)),
+        ]
+        sorted_analyses = sorted(analyses)
+        expected_analyses = reorder(analyses, expected_order)
+        self.assertListEqual(sorted_analyses, expected_analyses)
